@@ -9,7 +9,7 @@ use LWP::UserAgent;
 
 package RT::Extension::TOTPMFA;
 
-our $VERSION = '0.04';
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -26,8 +26,8 @@ passcodes (TOTP).
 To enable MFA, the "About me" page is extended with a new section alongside
 identity and password, for TOTP token management.  In this section, the user
 may scan a QR code based on this token into their mobile device's
-TOTP-compatible app, such as Google Authenticator.  Or, they can enrol the
-key for their Yubikey device on this page instead.
+TOTP-compatible app, such as FreeOTP+ or Google Authenticator.  Or, they can
+enrol the key for their Yubikey device on this page instead.
 
 When an account has MFA enabled, the RT login page works as usual, but the
 user is then prompted to enter a one-time passcode before they can proceed
@@ -132,6 +132,18 @@ is at L<https://codeberg.org/ivarch/rt-extension-totpmfa/issues>.
 
 Copyright 2025 Andrew Wood.
 
+Contributors include:
+
+=over
+
+=item *
+
+L<elacour|https://codeberg.org/elacour> - localisation support, French
+translation, inline QR code display, bugfix in secret reset, and packaging
+improvements.
+
+=back
+
 License GPLv3+: GNU GPL version 3 or later: L<https://gnu.org/licenses/gpl.html>
 
 This is free software: you are free to change and redistribute it.  There is
